package sun.management.snmp.jvminstr;

import java.net.UnknownHostException;
import java.net.InetAddress;

public class NotificationTargetImpl implements NotificationTarget
{
    private InetAddress address;
    private int port;
    private String community;
    
    public NotificationTargetImpl(String s) throws IllegalArgumentException, UnknownHostException {
        this.parseTarget(s);
    }
    
    public NotificationTargetImpl(String host, int n, String s) throws UnknownHostException {
        this(InetAddress.getByName(host), n, s);
    }
    
    public NotificationTargetImpl(InetAddress address, int port, String community) {
        this.address = address;
        this.port = port;
        this.community = community;
    }
    
    private void parseTarget(String str) throws IllegalArgumentException, UnknownHostException {
        if (str == null || str.length() == 0) {
            throw new IllegalArgumentException("Invalid target [" + str + "]");
        }
        String host;
        if (str.startsWith("[")) {
            int index2 = str.indexOf("]");
            int lastIndex2 = str.lastIndexOf(":");
            if (index2 == -1) {
                throw new IllegalArgumentException("Host starts with [ but does not end with ]");
            }
            host = str.substring(1, index2);
            this.port = Integer.parseInt(str.substring(index2 + 2, lastIndex2));
            if (!isNumericIPv6Address(host)) {
                throw new IllegalArgumentException("Address inside [...] must be numeric IPv6 address");
            }
            if (host.startsWith("[")) {
                throw new IllegalArgumentException("More than one [[...]]");
            }
        }
        else {
            int index = str.indexOf(":");
            int lastIndex = str.lastIndexOf(":");
            if (index == -1) {
                throw new IllegalArgumentException("Missing port separator \":\"");
            }
            host = str.substring(0, index);
            this.port = Integer.parseInt(str.substring(index + 1, lastIndex));
        }
        this.address = InetAddress.getByName(host);
        this.community = str.substring(str.lastIndexOf(":") + 1, str.length());
        return;
    }
    
    private static boolean isNumericIPv6Address(String s) {
        return s.indexOf(58) >= 0;
    }
    
    @Override
    public String getCommunity() {
        return this.community;
    }
    
    @Override
    public InetAddress getAddress() {
        return this.address;
    }
    
    @Override
    public int getPort() {
        return this.port;
    }
    
    @Override
    public String toString() {
        return "address : " + this.address + " port : " + this.port + " community : " + this.community;
    }
}
